"use strict";

exports.__esModule = true;
exports.useBodyScrollLock = useBodyScrollLock;

var _bodyScrollLock = require("body-scroll-lock");

var _vue = require("vue");

var _vueUtils = require("@chakra-ui/vue-utils");

/**
 * Enables body scroll locking
 * @param enable whether the scroll lock should be active or not
 * @param options BodyScrollLock options
 * @returns Ref of element to exclude from body scroll lock
 */
function useBodyScrollLock(enable, options) {
  var _useRef = (0, _vueUtils.useRef)(),
      scrollLockRef = _useRef[0],
      scrollLockEl = _useRef[1];

  (0, _vue.watch)([scrollLockEl, enable], function (_ref, _ref2) {
    var target = _ref[0],
        isActive = _ref[1];
    var previousTarget = _ref2[0];

    if (!target || !enable.value) {
      previousTarget && (0, _bodyScrollLock.enableBodyScroll)(previousTarget);
    } else if (target && isActive) {
      (0, _bodyScrollLock.disableBodyScroll)(target, options);
    } else {
      (0, _bodyScrollLock.enableBodyScroll)(target);
    }
  }, {
    immediate: true,
    flush: 'post'
  });
  return {
    scrollLockRef: scrollLockRef
  };
}
//# sourceMappingURL=use-body-scoll-lock.js.map