import { enableBodyScroll, disableBodyScroll } from 'body-scroll-lock';
import { watch } from 'vue';
import { useRef } from '@chakra-ui/vue-utils';
/**
 * Enables body scroll locking
 * @param enable whether the scroll lock should be active or not
 * @param options BodyScrollLock options
 * @returns Ref of element to exclude from body scroll lock
 */

export function useBodyScrollLock(enable, options) {
  var [scrollLockRef, scrollLockEl] = useRef();
  watch([scrollLockEl, enable], (_ref, _ref2) => {
    var [target, isActive] = _ref;
    var [previousTarget] = _ref2;

    if (!target || !enable.value) {
      previousTarget && enableBodyScroll(previousTarget);
    } else if (target && isActive) {
      disableBodyScroll(target, options);
    } else {
      enableBodyScroll(target);
    }
  }, {
    immediate: true,
    flush: 'post'
  });
  return {
    scrollLockRef
  };
}
//# sourceMappingURL=use-body-scoll-lock.js.map